@@ -1,4 +1,5 @@
 require "spec_helper"
+require "etc"
 require "logger"
 require "timeout"
 
@@ -386,7 +387,7 @@ describe Mixlib::ShellOut do
           it "should preserve custom variables" do
             expect(shell_cmd.process_environment["PATH"]).to eq("/lord:/of/the/dance")
           end
-                # Setting the user with additional env variables should have both
+          # Setting the user with additional env variables should have both
           it "should allow new variables" do
             expect(shell_cmd.process_environment["CUSTOM"]).to eq("costume")
           end
@@ -459,7 +460,7 @@ describe Mixlib::ShellOut do
         expect(shell_cmd.umask).to eql(002222)
       end
 
-      it "should set the timout" do
+      it "should set the timeout" do
         expect(shell_cmd.timeout).to eql(timeout)
       end
 
@@ -471,7 +472,7 @@ describe Mixlib::ShellOut do
         context "when setting the :env option" do
           let(:options) { { env: environment } }
 
-          it "should also set the enviroment" do
+          it "should also set the environment" do
             expect(shell_cmd.environment).to eql({ "RUBY_OPTS" => "-w" })
           end
         end
@@ -636,7 +637,12 @@ describe Mixlib::ShellOut do
         # to match how whoami returns the information
 
         it "should run as current user" do
-          expect(running_user).to eql("#{ENV["USERDOMAIN"].downcase}\\#{ENV["USERNAME"].downcase}")
+          if ENV["USERNAME"] == "#{ENV["COMPUTERNAME"]}$"
+            expected_user = "nt authority\\system"
+          else
+            expected_user = "#{ENV["USERDOMAIN"].downcase}\\#{ENV["USERNAME"].downcase}"
+          end
+          expect(running_user).to eql(expected_user)
         end
       end
 
@@ -657,6 +663,21 @@ describe Mixlib::ShellOut do
           expect(running_user).to eql("#{ENV["COMPUTERNAME"].downcase}\\#{user}")
         end
 
+        context "when an alternate user is passed" do
+          let(:env_list) { ["ALLUSERSPROFILE=C:\\ProgramData", "TEMP=C:\\Windows\\TEMP", "TMP=C:\\Windows\\TEMP", "USERDOMAIN=WIN-G06ENRTTKF9", "USERNAME=testuser", "USERPROFILE=C:\\Users\\Default", "windir=C:\\Windows"] }
+          let(:current_env) { ["ALLUSERSPROFILE=C:\\ProgramData", "TEMP=C:\\Users\\ADMINI~1\\AppData\\Local\\Temp\\2", "TMP=C:\\Users\\ADMINI~1\\AppData\\Local\\Temp\\2", "USER=Administrator", "USERDOMAIN=WIN-G06ENRTTKF9", "USERDOMAIN_ROAMINGPROFILE=WIN-G06ENRTTKF9", "USERNAME=Administrator", "USERPROFILE=C:\\Users\\Administrator", "windir=C:\\Windows"] }
+          let(:merged_env) { ["ALLUSERSPROFILE=C:\\ProgramData", "TEMP=C:\\Windows\\TEMP", "TMP=C:\\Windows\\TEMP", "USER=Administrator", "USERDOMAIN=WIN-G06ENRTTKF9", "USERDOMAIN_ROAMINGPROFILE=WIN-G06ENRTTKF9", "USERNAME=testuser", "USERPROFILE=C:\\Users\\Default", "windir=C:\\Windows"] }
+          let(:converted) { { "ALLUSERSPROFILE" => "C:\\ProgramData", "TEMP" => "C:\\Windows\\TEMP", "TMP" => "C:\\Windows\\TEMP", "USERDOMAIN" => "WIN-G06ENRTTKF9", "USERNAME" => "testuser", "USERPROFILE" => "C:\\Users\\Default", "windir" => "C:\\Windows" } }
+
+          it "merge environment variables" do
+            expect(Process.merge_env_variables(env_list, current_env)).to eql(merged_env)
+          end
+
+          it "Convert an array to a hash" do
+            expect(Process.environment_list_to_hash(env_list)).to eql(converted)
+          end
+        end
+
         context "when :elevated => true" do
           context "when user and password are passed" do
             let(:options) { { user: user, password: password, elevated: true } }
@@ -771,16 +792,12 @@ describe Mixlib::ShellOut do
             end
 
             context "when not using a batch file" do
-              let(:cmd) { "#{executable_file_name} #{script_name}" }
-
-              let(:executable_file_name) { "\"#{dir}/Ruby Parser.exe\"".tap(&make_executable!) }
-              let(:make_executable!) { lambda { |filename| Mixlib::ShellOut.new("copy \"#{full_path_to_ruby}\" #{filename}").run_command } }
-              let(:script_content) { "print \"#{expected_output}\"" }
+              let(:cmd) { "#{executable_file_name} -command #{script_content}" }
+              let(:executable_file_name) { "\"#{dir}/Powershell Parser.exe\"".tap(&make_executable!) }
+              let(:make_executable!) { lambda { |filename| Mixlib::ShellOut.new("copy \"c:\\windows\\system32\\WindowsPowerShell\\v1.0\\powershell.exe\" #{filename}").run_command } }
+              let(:script_content) { "Write-Host \"#{expected_output}\"" }
               let(:expected_output) { "Random #{rand(10000)}" }
 
-              let(:full_path_to_ruby) { ENV["PATH"].split(";").map(&try_ruby).reject(&:nil?).first }
-              let(:try_ruby) { lambda { |path| "#{path}\\ruby.exe" if File.executable? "#{path}\\ruby.exe" } }
-
               it "should execute" do
                 is_expected.to eql(expected_output)
               end
@@ -1094,7 +1111,7 @@ describe Mixlib::ShellOut do
         end
 
         after do
-          @test_file.close if @test_file
+          @test_file&.close
         end
 
         let(:ruby_code) { "fd = File.for_fd(#{@test_file.to_i}) rescue nil; if fd; fd.seek(0); puts fd.read(5); end" }
@@ -1379,7 +1396,7 @@ describe Mixlib::ShellOut do
       end
 
       context "with subprocess writing lots of data to both stdout and stderr" do
-        let(:expected_output_with) { lambda { |chr| (chr * 20_000) + (LINE_ENDING).to_s + (chr * 20_000) + (LINE_ENDING).to_s } }
+        let(:expected_output_with) { lambda { |chr| (chr * 20_000) + LINE_ENDING.to_s + (chr * 20_000) + LINE_ENDING.to_s } }
 
         context "when writing to STDOUT first" do
           let(:ruby_code) { %q{puts "f" * 20_000; STDERR.puts "u" * 20_000; puts "f" * 20_000; STDERR.puts "u" * 20_000} }
@@ -1532,7 +1549,7 @@ describe Mixlib::ShellOut do
 
     context "when no user is set" do
       it "should run as current user" do
-        expect(running_user).to eql(ENV["USER"])
+        expect(running_user).to eql(Etc.getpwuid.name)
       end
     end
 
@@ -1542,7 +1559,7 @@ describe Mixlib::ShellOut do
       let(:options) { { user: user } }
 
       it "should run as specified user" do
-        expect(running_user).to eql((user).to_s)
+        expect(running_user).to eql(user.to_s)
       end
     end
   end
