@@ -1,5 +1,3 @@
-$:.unshift File.expand_path("../../lib", __FILE__)
-$:.unshift File.expand_path("../..", __FILE__)
 require "mixlib/shellout"
 
 require "tmpdir"
@@ -7,8 +5,7 @@ require "tempfile"
 require "timeout"
 
 # Load everything from spec/support
-# Do not change the gsub.
-Dir["spec/support/**/*.rb"].map { |f| f.gsub(/.rb$/, "") }.each { |f| require f }
+Dir["spec/support/**/*.rb"].each { |f| require File.expand_path(f) }
 
 RSpec.configure do |config|
   config.mock_with :rspec
@@ -19,6 +16,7 @@ RSpec.configure do |config|
   config.filter_run_excluding windows_only: true unless windows?
   config.filter_run_excluding unix_only: true unless unix?
   config.filter_run_excluding requires_root: true unless root?
+  config.filter_run_excluding ruby: DependencyProc.with(RUBY_VERSION)
 
   config.run_all_when_everything_filtered = true
 
